from quickhttp.cli import app

app(prog_name="python -m quickhttp")
